# zope imports
from zope.interface import Interface
from zope.interface import implements

# Five imports
from Products.Five.browser import BrowserView

# CMFCore imports
from Products.CMFCore.utils import getToolByName

# EasyArticle imports 
from Products.EasyArticle.interfaces import IObjectManagement
from Products.EasyArticle.interfaces import IEAReferenceContent

class IArticleView(Interface):    
    """    
    """
    def getObjects():
        """Returns all objects in the right order of an article.
        """    
        
    def getReferences():
        """Returns just the references of an article.
        """

    def showEditFunctions():
        """Returns True if the edit functions are to be displayed.
        """
        
class ArticleView(BrowserView):
    """
    """
    implements(IArticleView)

    def getObjects(self, portal_types=None):
        """
        """
        om = IObjectManagement(self.context)
        objects = om.getObjects(portal_types)
            
        result = []
        for index, object in enumerate(objects):

            # Create the edit function urls
            edit_url   = "%s/base_edit" % object.absolute_url()

            delete_url = "%s/ea_delete_confirmation" % object.absolute_url()                        
            
            up_url     = "%s/ea_folder_position?position=up&id=%s" % (
                            self.context.absolute_url(), 
                            object.getId())                
                            
            down_url   = "%s/ea_folder_position?position=down&id=%s" % (
                            self.context.absolute_url(), 
                            object.getId())

            # Note: Move here to the referenced object
            if IEAReferenceContent.providedBy(object):
                object = object.getObjectReference()
                if object is None:
                    continue

            try:
                text = object.getText()
            except AttributeError:
                text = ""

            # This may be useful to make the template (view) cleaner (i.e.:
            # add a <hr/> on every row, but last)
            if index == len(objects) - 1:
                klass = "last"
            else:
                klass = "not-last"

            result.append({
                "portal_type" : object.getPortalTypeName(),
                "url"         : object.absolute_url(),
                "edit_url"    : edit_url,
                "delete_url"  : delete_url,
                "up_url"      : up_url,
                "down_url"    : down_url,
                "title"       : object.Title(),
                "description" : object.Description(),
                "text"        : text,
                "class"       : klass,
            })
        
        return result

    def getReferences():
        """
        """
        return self.getObjects(["EAReference"])
        
    def showEditFunctions(self):
        """
        """
        mtool = getToolByName(self.context, "portal_membership")
        
        # "not" works for both: None and False
        if not mtool.checkPermission("Manage portal", self.context):
            return False
            
        return True

